@@ -17,3 +17,10 @@
 #undef PACKAGE
 #undef VERSION
 #undef USE_XOPEN_SOURCE
+#undef GNOME_ICONDIR
+#undef USING_OAF
+#undef WITH_USB_VISOR
+#undef WITH_IRDA
+#undef WITH_NETWORK
+#undef WITH_VFS
+
