@@ -108,6 +108,19 @@ static void pilot_execute_program (const gchar *);
 
 /******************************************************************/
 
+static void
+gpilotd_set_style (GtkWidget *w) {
+	GtkStyle *style;
+
+	if (w == NULL) {
+		return;
+	}
+
+	style = gtk_style_copy (w->style);
+	style->font = gdk_font_load ("6x8");
+	gtk_widget_set_style (w, style);
+}
+
 static void 
 gpilotd_connect_cb (GnomePilotClient* client, 
 		    const gchar *id,
@@ -136,6 +149,20 @@ gpilotd_connect_cb (GnomePilotClient* client,
 		overall_progress_bar=glade_xml_get_widget (xml,"overall_progress_bar");
 		conduit_progress_bar=glade_xml_get_widget (xml,"conduit_progress_bar");
 		cancel_button=glade_xml_get_widget (xml,"cancel_button");
+/*
+		gpilotd_set_style (progressDialog);
+		gpilotd_set_style (glade_xml_get_widget (xml, "main_vbox"));
+		gpilotd_set_style (glade_xml_get_widget (xml, "action_area"));
+		gpilotd_set_style (glade_xml_get_widget (xml, "inner_vbox"));
+		gpilotd_set_style (glade_xml_get_widget (xml, "scrolled_window"));
+		gpilotd_set_style (glade_xml_get_widget (xml, "view_port"));
+		gpilotd_set_style (sync_label);
+		gpilotd_set_style (message_area);
+		gpilotd_set_style (overall_progress_bar);
+		gpilotd_set_style (conduit_progress_bar);
+		gpilotd_set_style (cancel_button);
+*/
+
 		gtk_signal_connect (GTK_OBJECT (cancel_button),"clicked",
 				   GTK_SIGNAL_FUNC (cancel_cb),NULL);
 	} else {
@@ -256,6 +283,7 @@ gpilotd_conduit_progress (GnomePilotClient* client,
 		gtk_progress_set_format_string (GTK_PROGRESS (conduit_progress_bar), _("%v of %u records"));
 		gpilot_applet_progress_stop (c_progress);
 	}
+	g_main_iteration (FALSE);
 }
 
 static void 
@@ -273,6 +301,7 @@ gpilotd_overall_progress (GnomePilotClient* client,
 	if (properties.popups && progressDialog!=NULL) {
 		gtk_progress_configure (GTK_PROGRESS (overall_progress_bar),cur_f,0,tot_f);
 	}
+	g_main_iteration (FALSE);
 }
 
 static void 
@@ -287,6 +316,7 @@ gpilotd_conduit_message (GnomePilotClient* client,
 		gtk_text_insert (GTK_TEXT (message_area),NULL,NULL,NULL,txt,-1);
 		g_free (txt);
 	}
+	g_main_iteration (FALSE);
 }
 
 static void 
@@ -301,6 +331,7 @@ gpilotd_daemon_message (GnomePilotClient* client,
 		gtk_text_insert (GTK_TEXT (message_area),NULL,NULL,NULL,txt,-1);
 		g_free (txt);
 	}
+	g_main_iteration (FALSE);
 }
 
 static void 
