@@ -571,6 +571,7 @@ gpcc_conduits_settings (GtkWidget *widget, gpointer user_data)
 		if (gnome_pilot_cdialog_run_and_close (GNOME_PILOT_CDIALOG (state->settings_widget2))) {
 			/* pressed ok */
 			state->sync_type = gnome_pilot_cdialog_sync_type (GNOME_PILOT_CDIALOG (state->settings_widget2));
+			state->first_sync_type = gnome_pilot_cdialog_first_sync_type (GNOME_PILOT_CDIALOG (state->settings_widget2));
 			state->enabled = (state->sync_type != GnomePilotConduitSyncTypeNotSet);
 			state->changed=TRUE;
 			
@@ -675,8 +676,10 @@ conduit_try_foreach (gpointer key, gpointer value, gpointer func)
 			else
 				gnome_pilot_conduit_config_enable_with_first_sync (state->config,
 										   state->sync_type,
-										   state->sync_type,
+										   state->first_sync_type,
 										   TRUE);
+			if (state->first_sync_type == GnomePilotConduitSyncTypeNotSet)
+				gnome_pilot_conduit_config_remove_first_sync (state->config);
 		}
 		
 		if (state->changed && !state->enabled)
@@ -716,6 +719,7 @@ conduit_revert_foreach (gpointer key, gpointer value, gpointer func)
 			
 			state->enabled = state->orig_enabled;
 			state->sync_type = state->orig_sync_type;
+			state->first_sync_type = state->orig_first_sync_type;
 		}
 		
 		if (state->changed && !state->orig_enabled) {
