@@ -24,8 +24,10 @@
 
 #include <stdio.h>
 #include <sys/stat.h>
+#include <errno.h>
 #include <ctype.h>
 #include <glade/glade.h>
+#include <errno.h>
 #include "util.h"
 
 static const guint speedList[] = {9600, 19200, 38400, 57600, 115200, 0};
@@ -79,6 +81,7 @@ fill_synctype_menu (GtkOptionMenu *option_menu, GnomePilotConduitSyncType type)
 	GtkMenu *menu;
 	GtkWidget *menu_item;
 	int i;
+	int choice = 0;
 	
 	menu = GTK_MENU (gtk_menu_new ());
 
@@ -88,11 +91,13 @@ fill_synctype_menu (GtkOptionMenu *option_menu, GnomePilotConduitSyncType type)
 		gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (syncvalues[i]));
 		gtk_menu_append (menu, menu_item);
 
-		if (type == syncvalues[i])
-			gtk_option_menu_set_history (option_menu, i);
+		if (type == syncvalues[i]) {
+			choice = i;
+		}			
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu),GTK_WIDGET (menu));
+	gtk_option_menu_set_history (option_menu, choice);
 }
 
 void 
@@ -105,7 +110,6 @@ fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
 	
 	menu = GTK_MENU (gtk_menu_new ());
 
-	/* Add the disabled item first. */
 	menu_item = gtk_menu_item_new_with_label(_("Disabled"));
 	gtk_widget_show(menu_item);
 	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
@@ -137,6 +141,37 @@ fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
 	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
 }
 
+void 
+fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
+{
+	GtkWidget *menu_item;
+	GtkMenu   *menu;
+	GList *tmp;
+	int index, current=0;
+	
+	menu = GTK_MENU (gtk_menu_new ());
+
+	menu_item = gtk_menu_item_new_with_label(_("None"));
+	gtk_widget_show(menu_item);
+	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
+	gtk_menu_append (menu, menu_item);
+
+	tmp = state->valid_synctypes;
+	for (index = 0; tmp != NULL; tmp = tmp->next, index++) {
+		gint value = GPOINTER_TO_INT (tmp->data);
+		
+		menu_item = gtk_menu_item_new_with_label (sync_type_to_str (value));
+		gtk_widget_show (menu_item);
+		gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (value));
+		gtk_menu_append (menu,menu_item);
+		if (value == state->first_sync_type) 
+			current = index + 1;
+	}
+
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), GTK_WIDGET (menu));
+	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
+}
+
 void
 show_popup_menu (GtkCList *list, GdkEventButton *event, GtkMenu *menu)
 {
