@@ -27,20 +27,23 @@
 #include "config.h"
 #endif
 
+/* for crypt () */
 #ifdef USE_XOPEN_SOURCE
+#ifndef _XOPEN_SOURCE
 #define _XOPEN_SOURCE 
+#endif /* _XOPEN_SOURCE  */
 #endif
 
-#include <glib.h>
-
-#include <pwd.h>
-#include <errno.h>
-#include <string.h>
-#include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <sys/time.h>
+
+#include <glib.h>
+#include <pwd.h>
+#include <errno.h>
+#include <string.h>
+#include <signal.h>
 #include <unistd.h>
 #include <stdio.h>
 
